#! /usr/bin/env node
'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _winston = require('winston');

var _winston2 = _interopRequireDefault(_winston);

var _postContentValidator = require('./post-content-validator');

var _postContentValidator2 = _interopRequireDefault(_postContentValidator);

var _postUrlValidator = require('./post-url-validator');

var _postUrlValidator2 = _interopRequireDefault(_postUrlValidator);

var _imageProcessor = require('./image-processor');

var _imageProcessor2 = _interopRequireDefault(_imageProcessor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var winstonTimerLevel = 'info';

require('winston-timer')(_winston2.default, {
  level: winstonTimerLevel,
  use_colors: false
});

var postsGlob = _path2.default.join(process.cwd(), '**/_posts/*');
var _siteFolder = _path2.default.join(process.cwd(), '/_site');

process.on('unhandledRejection', function (reason) {
  throw reason;
});

_winston2.default.info('ritter-jekyll ' + require('../package.json').version);

runWithTimings('Validating post urls', function () {
  new _postUrlValidator2.default().validate(postsGlob);
});

runWithTimings('Validating post contents', function () {
  new _postContentValidator2.default().validate(postsGlob);
});

if (process.env.NODE_ENV === 'production') {
  _winston2.default.start_log('Running image processor');
  new _imageProcessor2.default().run(_siteFolder + '/images').then(function () {
    _winston2.default.stop_log('Running image processor', winstonTimerLevel);
  });
}

function runWithTimings(msg, fn) {
  _winston2.default.start_log(msg);
  fn();
  _winston2.default.stop_log(msg, winstonTimerLevel);
}